@@ -1,10 +1,11 @@
 from rich import print
-from . import install as i
-__version__ = '0.1.1'
+from pnpm import install as i
 
+__version__ = '0.2.1'
 
 def whoisthis():
     print(f"This is {__version__}")
-    
-def install():
+
+def _install():
     i.install()
+    
\ No newline at end of file
